calculate_distance: Functions to calculate distance matrices using cpu or gpu...

Description Usage Arguments Value Author(s) Examples

Description

Functions to calculate distance matrices using cpu or gpu computing

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
16
17

Arguments

x

an expression matrix with features as rows and samples as columns

distancetype

a character that can be either 'pearson', 'uncentered', 'spearman' or 'euclidean'

usegpu

logical TRUE or FALSE

Value

select_distance(distancetype, usegpu) assigns global function calculate_distance according to the parameters specified

calculate_distance_pearson_gpu(x) returns columnwise pearson distance calculated using the GPU

calculate_distance_pearson_cpu(x) returns columnwise pearson distance calculated using the CPU

calculate_distance_uncentered_gpu(x) returns columnwise uncentered pearson distance calculated using the GPU

calculate_distance_uncentered_cpu(x) returns columnwise uncentered pearson distance calculated using the CPU

calculate_distance_spearman_gpu(x) returns columnwise spearman distance calculated using the GPU

calculate_distance_spearman_cpu(x) returns columnwise spearman distance calculated using the CPU

calculate_distance_euclidean_gpu(x) returns columnwise euclidean distance calculated using the GPU

calculate_distance_euclidean_cpu(x) returns columnwise euclidean distance calculated using the CPU

Author(s)

Martin E Guerrero-Gimenez, mguerrero@mendoza-conicet.gob.ar

Examples

1
2
3
4
5
6
7
8
## Not run: 
rna_luad<-use_rna_luad()
prm <- rna_luad$TCGA$expression_matrix
#Will select the calculate_distance_pearson_cpu() function to calculate the distance matrix
calculate_distance<-select_distance(distancetype= "pearson", usegpu=FALSE)
calculate_distance(prm)

## End(Not run)

harpomaxx/galgo documentation built on Aug. 11, 2020, 3:07 p.m.