Description Usage Arguments Value Author(s) Examples
galgo accepts an expression matrix and a survival object to find robust gene expression signatures related to a given outcome
1 2 3 4 5 6 7 8 | galgo(population = 30, generations = 2, nCV = 5, usegpu = FALSE,
distancetype = "pearson", TournamentSize = 2, period = 1825, OS,
prob_matrix, res_dir = "",
save_pop_partial_callback = default_callback,
save_pop_final_callback = base_return_pop_callback,
report_callback = base_report_callback,
start_gen_callback = base_start_gen_callback,
end_gen_callback = base_end_gen_callback, verbose = 2)
|
population |
a number indicating the number of solutions in the population of solutions that will be evolved |
generations |
a number indicating the number of iterations of the galgo algorithm |
nCV |
number of cross-validation sets |
usegpu |
|
distancetype |
character, it can be |
TournamentSize |
a number indicating the size of the tournaments for the selection procedure |
period |
a number indicating the outcome period to evaluate the RMST |
OS |
a |
prob_matrix |
a |
res_dir |
a |
save_pop_partial_callback |
optional callback function between iterations |
save_pop_final_callback |
optional callback function for the last iteration |
report_callback |
optional callback function |
start_gen_callback |
optional callback function for the beginning of the run |
end_gen_callback |
optional callback function for the end of the run |
verbose |
select the level of information printed during galgo execution |
an object of type 'galgo.Obj' that corresponds to a list with the elements $Solutions and $ParetoFront. $Solutions is a l x (n + 5) matrix where n is the number of features evaluated and l is the number of solutions obtained.
The submatrix l x n is a binary matrix where each row represents the chromosome of an evolved solution from the solution population, where each feature can be present (1) or absent (0) in the solution. Column n +1 represent the k number of clusters for each solutions. Column n+2 to n+5 shows the SC Fitness and Survival Fitness values, the solution rank, and the crowding distance of the solution in the final pareto front respectively.
For easier interpretation of the 'galgo.Obj', the output can be reshaped using the toList and toDataFrame functions
Martin E Guerrero-Gimenez, mguerrero@mendoza-conicet.gob.ar
1 2 3 4 5 6 7 8 9 10 11 12 13 | ## Not run:
#Load data
rna_luad <- use_rna_luad()
TCGA_expr <- rna_luad$TCGA$expression_matrix
TCGA_clinic <- rna_luad$TCGA$pheno_data
OS <- survival::Surv(time=TCGA_clinic$time,event=TCGA_clinic$status)
#Run galgo
output <- galgoR::galgo(generations = 10 ,population = 30, prob_matrix = TCGA_expr, OS = OS)
outputDF <- toDataFrame(output)
outputList <- toList(output)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.