plot_pareto: Plot pareto front from an galgo.Obj

Description Usage Arguments Value Examples

View source: R/results_functions.R

Description

Plot pareto front from an galgo.Obj

Usage

1
plot_pareto(output)

Arguments

output

An object of class galgo.Obj

Value

This function returns a scatterplot showing the solutions found by Galgo accross all generations in the solution space, where the Silhouette Fitness is in the x-axis and the survival fitness in the y-axis. A line is drawn over all non-dominated solutions showing the estimated Pareto front

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
## Not run: 
# Load data
rna_luad <- use_rna_luad()
TCGA_expr <- rna_luad$TCGA$expression_matrix
TCGA_clinic <- rna_luad$TCGA$pheno_data
OS <- survival::Surv(time = TCGA_clinic$time, event = TCGA_clinic$status)

# Run galgo
output <- galgoR::galgo(generations = 10, population = 30, prob_matrix = TCGA_expr, OS = OS)
plot_pareto(output)

## End(Not run)

harpomaxx/galgo documentation built on Aug. 11, 2020, 3:07 p.m.