Description Usage Arguments Value Examples
View source: R/results_functions.R
The function uses a 'galgo.Obj' as input an the training dataset to evaluate the non-dominated solutions found by GalgoR
1 2 | non_dominated_summary(output, prob_matrix, OS, distancetype = "pearson",
usegpu = FALSE)
|
output |
An object of class |
prob_matrix |
a |
OS |
a |
distancetype |
a |
usegpu |
|
Returns a data.frame with 5 columns and a number of rows equals to the non-dominated solutions found by GalgoR.
The first column has the name of the non-dominated solutions, the second the number of partitions found for each solution (k), the third, the number of genes, the fourth the mean silhouette coefficient of the solution and the last columns has the estimated C.Index for each one.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 | ## Not run:
# Load data
rna_luad <- use_rna_luad()
TCGA_expr <- rna_luad$TCGA$expression_matrix
TCGA_clinic <- rna_luad$TCGA$pheno_data
OS <- survival::Surv(time = TCGA_clinic$time, event = TCGA_clinic$status)
# Run galgo
output <- galgoR::galgo(generations = 10, population = 30, prob_matrix = TCGA_expr, OS = OS)
non_dominated_summary(
output = output, OS = OS,
prob_matrix = TCGA_expr,
distancetype = "pearson",
usegpu = FALSE
)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.